==> core-0.1.42.tgz: package/esm/drivers/MouseClickDriver.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { EventDriver } from '@designable/shared';
import { MouseClickEvent } from '../events';
var MouseClickDriver = (function (_super) {
    __extends(MouseClickDriver, _super);
    function MouseClickDriver() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onMouseClick = function (e) {
            var target = e.target;
            if (target === null || target === void 0 ? void 0 : target.closest('*[data-click-stop-propagation]')) {
                return;
            }
            _this.dispatch(new MouseClickEvent({
                clientX: e.clientX,
                clientY: e.clientY,
                pageX: e.pageX,
                pageY: e.pageY,
                target: e.target,
                view: e.view,
            }));
        };
        return _this;
    }
    MouseClickDriver.prototype.attach = function () {
        this.addEventListener('click', this.onMouseClick, {
            once: true,
        });
    };
    MouseClickDriver.prototype.detach = function () {
        this.removeEventListener('click', this.onMouseClick, {
            once: true,
        });
    };
    return MouseClickDriver;
}(EventDriver));
export { MouseClickDriver };

==> core-0.5.3.tgz: package/esm/drivers/MouseClickDriver.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { EventDriver } from '@designable/shared';
import { MouseClickEvent, MouseDoubleClickEvent } from '../events';
var MouseClickDriver = /** @class */ (function (_super) {
    __extends(MouseClickDriver, _super);
    function MouseClickDriver() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onMouseClick = function (e) {
            var target = e.target;
            if (target === null || target === void 0 ? void 0 : target.closest("*[" + _this.engine.props.clickStopPropagationAttrName + "]")) {
                return;
            }
            _this.dispatch(new MouseClickEvent({
                clientX: e.clientX,
                clientY: e.clientY,
                pageX: e.pageX,
                pageY: e.pageY,
                target: e.target,
                view: e.view,
            }));
        };
        _this.onMouseDoubleClick = function (e) {
            var target = e.target;
            if (target === null || target === void 0 ? void 0 : target.closest("*[" + _this.engine.props.clickStopPropagationAttrName + "]")) {
                return;
            }
            _this.dispatch(new MouseDoubleClickEvent({
                clientX: e.clientX,
                clientY: e.clientY,
                pageX: e.pageX,
                pageY: e.pageY,
                target: e.target,
                view: e.view,
            }));
        };
        return _this;
    }
    MouseClickDriver.prototype.attach = function () {
        this.addEventListener('click', this.onMouseClick, {
            once: true,
        });
        this.addEventListener('dblclick', this.onMouseDoubleClick, {
            once: true,
        });
    };
    MouseClickDriver.prototype.detach = function () {
        this.removeEventListener('click', this.onMouseClick, {
            once: true,
        });
        this.removeEventListener('dblclick', this.onMouseDoubleClick, {
            once: true,
        });
    };
    return MouseClickDriver;
}(EventDriver));
export { MouseClickDriver };
